@@ -196,7 +196,8 @@ def create_test_server(clients, validatable=False, validation_resources=None,
     """
 
     if name is None:
-        name = data_utils.rand_name(__name__ + "-instance")
+        name = data_utils.rand_name(
+            prefix=CONF.resource_name_prefix, name=__name__ + "-instance")
     if flavor is None:
         flavor = CONF.compute.flavor_ref
     if image_id is None:
@@ -245,7 +246,8 @@ def create_test_server(clients, validatable=False, validation_resources=None,
             kwargs['user_data'] = script_b64
 
     if volume_backed:
-        volume_name = data_utils.rand_name(__name__ + '-volume')
+        volume_name = data_utils.rand_name(
+            prefix=CONF.resource_name_prefix, name=__name__ + '-volume')
         volumes_client = clients.volumes_client_latest
         params = {'name': volume_name,
                   'imageRef': image_id,
@@ -253,6 +255,9 @@ def create_test_server(clients, validatable=False, validation_resources=None,
         if CONF.compute.compute_volume_common_az:
             params.setdefault('availability_zone',
                               CONF.compute.compute_volume_common_az)
+        if CONF.volume.volume_type:
+            params.setdefault('volume_type',
+                              CONF.volume.volume_type)
         volume = volumes_client.create_volume(**params)
         try:
             waiters.wait_for_volume_resource_status(volumes_client,
@@ -299,16 +304,15 @@ def create_test_server(clients, validatable=False, validation_resources=None,
 
     if wait_until:
 
-        if wait_until == 'SSHABLE' and not (
-                validatable and validation_resources is not None):
-            raise RuntimeError('SSHABLE requires validatable=True and '
-                               'validation_resources to be passed')
-
         # NOTE(lyarwood): PINGABLE and SSHABLE both require the instance to
         # go ACTIVE initially before we can setup the fip(s) etc so stash
         # this additional wait state for later use.
         wait_until_extra = None
         if wait_until in ['PINGABLE', 'SSHABLE']:
+            if not validatable and validation_resources is None:
+                raise RuntimeError(
+                    'SSHABLE/PINGABLE requires validatable=True '
+                    'and validation_resources to be passed')
             wait_until_extra = wait_until
             wait_until = 'ACTIVE'
 
@@ -376,19 +380,22 @@ def shelve_server(servers_client, server_id, force_shelve_offload=False):
                                  is configured not to offload server
                                  automatically after offload time.
     """
-    servers_client.shelve_server(server_id)
+    body = servers_client.shelve_server(server_id)
+    request_id = body.response['x-openstack-request-id']
 
     offload_time = CONF.compute.shelved_offload_time
     if offload_time >= 0:
         waiters.wait_for_server_status(servers_client, server_id,
                                        'SHELVED_OFFLOADED',
-                                       extra_timeout=offload_time)
+                                       extra_timeout=offload_time,
+                                       request_id=request_id)
     else:
         waiters.wait_for_server_status(servers_client, server_id, 'SHELVED')
         if force_shelve_offload:
             servers_client.shelve_offload_server(server_id)
             waiters.wait_for_server_status(servers_client, server_id,
-                                           'SHELVED_OFFLOADED')
+                                           'SHELVED_OFFLOADED',
+                                           request_id=request_id)
 
 
 def create_websocket(url):
@@ -420,7 +427,7 @@ def create_websocket(url):
 
 class _WebSocket(object):
     def __init__(self, client_socket, url):
-        """Contructor for the WebSocket wrapper to the socket."""
+        """Constructor for the WebSocket wrapper to the socket."""
         self._socket = client_socket
         # cached stream for early frames.
         self.cached_stream = b''
